#!/usr/bin/env Python  
#coding=utf-8

from setuptools import setup
from setuptools import find_packages

setup(
    name='dueros',
    version='0.0.1',
    description = 'Testing API',
    author = 'dialog manager',
    author_email = 'dialogbot@163.com',
    url = '',
    license="MIT",
    keywords='dueros,api',
    packages=find_packages(),
    classifiers=[
        'Development Status :: 4 - Beta',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Topic :: Scientific/Engineering',
        'Topic :: Software Development',
        'Topic :: Scientific/Engineering :: Artificial Intelligence',
    ],
)
